@@ -3,10 +3,10 @@
 #	plot.localdepth function
 #	Author: Claudio Agostinelli and Mario Romanazzi
 #	E-mail: claudio@unive.it
-#	Date: September, 2, 2008
-#	Version: 0.1
+#	Date: February, 07, 2011
+#	Version: 0.2
 #
-#	Copyright (C) 2008 Claudio Agostinelli and Mario Romanazzi
+#	Copyright (C) 2011 Claudio Agostinelli and Mario Romanazzi
 #
 #############################################################
 
@@ -15,8 +15,14 @@ plot.localdepth <- function(x, xlab="Depth", ylab="Local Depth", main="DD plot",
     labels <- rownames(x$y)
   sdepth <- x$depth
   ldepth <- x$localdepth
-  sdepth <- (sdepth-min(sdepth))/(max(sdepth)-min(sdepth))
-  ldepth <- (ldepth-min(ldepth))/(max(ldepth)-min(ldepth))
+  if (max(sdepth)-min(sdepth))
+    sdepth <- (sdepth-min(sdepth))/(max(sdepth)-min(sdepth))
+  else
+    sdepth <- rep(1, length(sdepth))
+  if (max(ldepth)-min(ldepth))
+    ldepth <- (ldepth-min(ldepth))/(max(ldepth)-min(ldepth))
+  else
+    ldepth <- rep(1, length(ldepth))
   plot(x=sdepth, y=ldepth, xlab=xlab, ylab=ylab, main=main, ...)
   tomark <- sdepth > mark | ldepth > mark
   text(sdepth[tomark], ldepth[tomark], labels=labels[tomark], pos=3)
